#
# spec file for package maven-resolver
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _buildshell /bin/bash
%bcond_with tests
Name:           maven-resolver
Version:        1.7.3
Release:        150200.3.6.1
Summary:        Apache Maven Artifact Resolver library
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/resolver/
Source0:        http://archive.apache.org/dist/maven/resolver/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.tar.xz
BuildRequires:  ant
BuildRequires:  apache-commons-lang3
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  glassfish-annotation-api
BuildRequires:  google-guice
BuildRequires:  httpcomponents-client
BuildRequires:  httpcomponents-core
BuildRequires:  javapackages-local
BuildRequires:  jcl-over-slf4j
BuildRequires:  maven-wagon-provider-api
BuildRequires:  plexus-classworlds
BuildRequires:  plexus-utils
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildRequires:  unzip
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildArch:      noarch
%if %{with tests}
BuildRequires:  ant-junit
BuildRequires:  cglib
BuildRequires:  guava
BuildRequires:  mockito
BuildRequires:  objectweb-asm
BuildRequires:  objenesis
BuildRequires:  plexus-containers-component-annotations
%endif

%description
Apache Maven Artifact Resolver is a library for working with artifact
repositories and dependency resolution. Maven Artifact Resolver deals with the
specification of local repository, remote repository, developer workspaces,
artifact transports and artifact resolution.

%package api
Summary:        Maven Artifact Resolver API
Group:          Development/Libraries/Java

%description api
The application programming interface for the repository system.

%package spi
Summary:        Maven Artifact Resolver SPI
Group:          Development/Libraries/Java

%description spi
The service provider interface for repository system implementations and
repository connectors.

%package util
Summary:        Maven Artifact Resolver Utilities
Group:          Development/Libraries/Java

%description util
A collection of utility classes to ease usage of the repository system.

%package named-locks
Summary:        Maven Artifact Resolver Named Locks
Group:          Development/Libraries/Java

%description named-locks
A synchronization utility implementation using Named locks

%package impl
Summary:        Maven Artifact Resolver Implementation
Group:          Development/Libraries/Java

%description impl
An implementation of the repository system.

%package test-util
Summary:        Maven Artifact Resolver Test Utilities
Group:          Development/Libraries/Java

%description test-util
A collection of utility classes to ease testing of the repository system.

%package connector-basic
Summary:        Maven Artifact Resolver Connector Basic
Group:          Development/Libraries/Java

%description connector-basic
A repository connector implementation for repositories using URI-based layouts.

%package transport-classpath
Summary:        Maven Artifact Resolver Transport Classpath
Group:          Development/Libraries/Java

%description transport-classpath
A transport implementation for repositories using classpath:// URLs.

%package transport-file
Summary:        Maven Artifact Resolver Transport File
Group:          Development/Libraries/Java

%description transport-file
A transport implementation for repositories using file:// URLs.

%package transport-http
Summary:        Maven Artifact Resolver Transport HTTP
Group:          Development/Libraries/Java

%description transport-http
A transport implementation for repositories using http:// and https:// URLs.

%package transport-wagon
Summary:        Maven Artifact Resolver Transport Wagon
Group:          Development/Libraries/Java

%description transport-wagon
A transport implementation based on Maven Wagon.

%package        javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description    javadoc
This package provides %{summary}.

%prep
%setup -q -a1

# requires internet connection
rm maven-resolver-transport-http/src/test/java/org/eclipse/aether/transport/http/HttpTransporterTest.java

%pom_remove_plugin -r :bnd-maven-plugin
%pom_remove_plugin -r org.codehaus.mojo:animal-sniffer-maven-plugin
%pom_remove_plugin -r org.apache.maven.plugins:maven-enforcer-plugin

%pom_disable_module maven-resolver-demos
%pom_disable_module maven-resolver-named-locks-hazelcast
%pom_disable_module maven-resolver-named-locks-redisson
%pom_disable_module maven-resolver-transport-classpath

# generate OSGi manifests
for pom in $(find -mindepth 2 -name pom.xml) ; do
  %pom_add_plugin "org.apache.felix:maven-bundle-plugin" $pom \
  "<configuration>
    <instructions>
      <Bundle-SymbolicName>\${project.groupId}$(sed 's:./maven-resolver::;s:/pom.xml::;s:-:.:g' <<< $pom)</Bundle-SymbolicName>
      <Export-Package>!org.eclipse.aether.internal*,org.eclipse.aether*</Export-Package>
      <_nouses>true</_nouses>
    </instructions>
  </configuration>
  <executions>
    <execution>
      <id>create-manifest</id>
      <phase>process-classes</phase>
      <goals><goal>manifest</goal></goals>
    </execution>
  </executions>"
done
%pom_add_plugin "org.apache.maven.plugins:maven-jar-plugin" pom.xml \
"<configuration>
  <archive>
    <manifestFile>\${project.build.outputDirectory}/META-INF/MANIFEST.MF</manifestFile>
  </archive>
</configuration>"

%{mvn_package} :maven-resolver
%{mvn_package} :maven-resolver-{*}  @1
%{mvn_alias} 'org.apache.maven.resolver:maven-resolver{*}' 'org.eclipse.aether:aether@1'
%{mvn_alias} 'org.apache.maven.resolver:maven-resolver-transport-wagon' 'org.eclipse.aether:aether-connector-wagon'
%{mvn_file} ':maven-resolver{*}' %{name}/maven-resolver@1 aether/aether@1

# Try to avoid sucking in dependencies on packages that are not built at this moment
%pom_remove_parent .
%pom_remove_plugin :maven-jar-plugin .

%build
mkdir -p lib
build-jar-repository -s lib \
  atinject \
  commons-lang3 \
  glassfish-annotation-api \
  guice/google-guice-no_aop \
  httpcomponents/httpclient \
  httpcomponents/httpcore \
  maven-wagon/provider-api \
  org.eclipse.sisu.inject \
  org.eclipse.sisu.plexus \
  plexus-classworlds \
  plexus/utils \
  slf4j/api
%if %{with tests}
build-jar-repository -s lib \
  cglib/cglib \
  guava/guava \
  mockito/mockito-core \
  objectweb-asm/asm \
  objenesis/objenesis \
  plexus-containers/plexus-component-annotations \
  slf4j/simple
%endif
%{ant} \
%if %{without tests}
  -Dtest.skip=true \
%endif
  package javadoc

%{mvn_artifact} pom.xml

mkdir -p target/site/apidocs
for i in api spi test-util util named-locks impl connector-basic transport-classpath transport-file transport-http transport-wagon; do
  cp -r %{name}-${i}/target/site/apidocs target/site/apidocs/%{name}-${i}
  %{mvn_artifact} %{name}-${i}/pom.xml %{name}-${i}/target/%{name}-${i}-%{version}.jar
done

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files api -f .mfiles-api
%license LICENSE NOTICE

%files spi -f .mfiles-spi

%files util -f .mfiles-util

%files named-locks -f .mfiles-named-locks

%files impl -f .mfiles-impl

%files test-util -f .mfiles-test-util

%files connector-basic -f .mfiles-connector-basic

%files transport-classpath -f .mfiles-transport-classpath

%files transport-file -f .mfiles-transport-file

%files transport-http -f .mfiles-transport-http

%files transport-wagon -f .mfiles-transport-wagon

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Sat May 21 2022 fstrba@suse.com
- Add an alias for the wagon connector
* Wed Mar 30 2022 fstrba@suse.com
- Build against the standalone JavaEE modules unconditionally
* Sat Mar 19 2022 fstrba@suse.com
- Remove the javax.annotation:javax.annotation-api dependency on
  distribution versions that do not incorporate the JavaEE modules
* Thu Mar 17 2022 fstrba@suse.com
- Add the glassfish-annotation-api jar to the build classpath
* Fri Mar 11 2022 fstrba@suse.com
- Upgrade to upstream version 1.7.3
  * Bug
    + [MRESOLVER-96] - Dependency Injection fails after upgrading
    to Maven 3.6.2
    + [MRESOLVER-153] - resolver-status.properties file is corrupted
    due to concurrent writes
    + [MRESOLVER-171] - Resolver fails when compiled on Java 9+ an
    run on Java 8 due to JDK API breakage
    + [MRESOLVER-189] - Using semaphore-redisson followed by
    rwlock-redisson on many parallel build of the same project
    triggers redisson error
  * New Feature
    + [MRESOLVER-90] - HTML content in POM: Maven should validate
    content before storing in local repo
    + [MRESOLVER-145] - Introduce more SyncContext implementations
  * Improvement
    + [MRESOLVER-103] - Replace deprecated HttpClient classes
    + [MRESOLVER-104] - maven-resolver-demo-maven-plugin uses
    reserved artifactId
    + [MRESOLVER-147] - Upgrade to Java 8
    + [MRESOLVER-148] - Use vanilla Guice 4 instead of forked
    Guice 3
    + [MRESOLVER-156] - Active dependency management for Google
    Guice/Guava
    + [MRESOLVER-168] - add DEBUG message when downloading an
    artifact from repositories
    + [MRESOLVER-193] - Properly type lock key names in Redis
    + [MRESOLVER-197] - Minors improvements (umbrella)
    + [MRESOLVER-204] - Add a SessionData#computeIfAbsent method
    + [MRESOLVER-214] - Remove clirr configuration
  * Task
    + [MRESOLVER-141] - Review index-based access to collections
    + [MRESOLVER-151] - Enforce a checksum policy to be provided
    explicitly
    + [MRESOLVER-152] - Perform null checks when interface
    contracts require it
    + [MRESOLVER-154] - Move SyncContextFactory interface to SPI
    module
    + [MRESOLVER-155] - Make TrackingFileManager member of
    DefaultUpdateCheckManager
    + [MRESOLVER-158] - Simplify SimpleDigest class
    + [MRESOLVER-159] - Mark singleton components as Sisu Singletons
    + [MRESOLVER-160] - Deprecate ServiceLocator
    + [MRESOLVER-162] - Restore binary compatibility broken by
    MRESOLVER-154
    + [MRESOLVER-170] - Deprecate org.eclipse.aether.spi.log
    + [MRESOLVER-172] - Make TrackingFileManager shared singleton
    component
    + [MRESOLVER-173] - Drop deprecated AetherModule
    + [MRESOLVER-174] - Use all bindings in UTs and tests
    + [MRESOLVER-175] - Drop SyncContextFactory delegates in favor
    of a selector approach
    + [MRESOLVER-177] - Move pre-/post-processing of metadata from
    ResolveTask to DefaultMetadataResolver
    + [MRESOLVER-183] - Don't require optional dependencies for
    Redisson
    + [MRESOLVER-184] - Destroy Redisson semaphores if not used
    anymore
    + [MRESOLVER-186] - Update Maven version in Resolver Demo
    Snippets
    + [MRESOLVER-188] - Improve documentation on using the named
    locks with redis/hazelcast (umbrella)
    + [MRESOLVER-190] - [Regression] Revert MRESOLVER-184
    + [MRESOLVER-191] - Document how to analyze lock issues
    + [MRESOLVER-196] - Document named locks configuration options
    + [MRESOLVER-219] - Implement NamedLock with advisory file
    locking
    + [MRESOLVER-227] - Refactor NamedLockFactorySelector to a
    managed component
    + [MRESOLVER-232] - Make SimpleNamedLockFactorySelector logic
    reusable
  * Sub-task
    + [MRESOLVER-198] - Replace assert by simpler but equivalent
    calls
    + [MRESOLVER-199] - Java 8 improvements
    + [MRESOLVER-200] - Simplify conditions with the same result
    and avoid extra validations
    + [MRESOLVER-201] - Make variables final whenever possible
    + [MRESOLVER-202] - Use isEmpty() instead length() <= 0
  * Dependency upgrade
    + [MRESOLVER-185] - Upgrade Redisson to 3.15.6
  * Change of API and incompatible with maven-resolver < 1.7
* Thu Jan 13 2022 fstrba@suse.com
- Upgrade to upstream version 1.6.3
  * Bug
    + [MRESOLVER-153] - resolver-status.properties file is corrupted
    due to concurrent writes
    + [MRESOLVER-171] - Resolver fails when compiled on Java 9+ and
    run on Java 8 due to JDK API breakage
  * Improvement
    + [MRESOLVER-168] - add DEBUG message when downloading an
    artifact from repositories
  * Task
    + [MRESOLVER-177] - Move pre-/post-processing of metadata from
    ResolveTask to DefaultMetadataResolver
  * Needed for maven 3.8.4
- Removed patch:
  * maven-resolver-1.3.1-java8compat.patch
    + fixed upstream
* Tue May 11 2021 fstrba@suse.com
- Do not build/run the tests against the legacy guava20 package
* Mon Apr 26 2021 fstrba@suse.com
- Upgrade to upstream version 1.6.2
  * Sub-task
    + [MRESOLVER-139] - Make SimpleDigest use SHA-1 or MD5 only
    + [MRESOLVER-140] - Default to SHA-1 and MD5 hashing algorithms
  * Bug
    + [MRESOLVER-25] - Resume support is broken under high
    concurrency
    + [MRESOLVER-114] - ArtifactNotFoundExceptions when building in
    parallel
    + [MRESOLVER-129] - Exclusion has no setters
    + [MRESOLVER-137] - Make OSGi bundles reproducible
    + [MRESOLVER-138] - MRESOLVER-56 introduces severe performance
    regression
  * New Feature
    + [MRESOLVER-109] - AndDependencySelector should override
    toString
    + [MRESOLVER-115] - Make checksum algorithms configurable
    + [MRESOLVER-123] - Provide a global locking sync context by
    default
    + [MRESOLVER-131] - Introduce a Redisson-based
    SyncContextFactory
    + [MRESOLVER-165] - Add support for mirror selector on
    external:http:*
    + [MRESOLVER-166] - Add support for blocked
    repositories/mirrors
  * Improvement
    + [MRESOLVER-56] - Support SHA-256 and SHA-512 as checksums
    + [MRESOLVER-116] - Add page with all supported configuration
    options
    + [MRESOLVER-125] - Use type conversions returning primitives
    + [MRESOLVER-127] - Don't use boolean for property
    'aether.updateCheckManager.sessionState'
    + [MRESOLVER-136] - Migrate from maven-bundle-plugin to
    bnd-maven-plugin
  * Task
    + [MRESOLVER-119] - Turn log messages to SLF4J placeholders
    + [MRESOLVER-130] - Move GlobalSyncContextFactory to a separate
    module
    + [MRESOLVER-132] - Remove synchronization in
    TrackingFileManager
  * Dependency upgrade
    + [MRESOLVER-105] - Update Plexus Components
    + [MRESOLVER-106] - Update HttpComponents
    + [MRESOLVER-107] - Update Wagon Provider API to 3.4.0
    + [MRESOLVER-108] - Update mockito-core to 2.28.2
    + [MRESOLVER-117] - Upgrade SLF4J to 1.7.30
    + [MRESOLVER-118] - Upgrade Sisu Components to 0.3.4
  * Needed for maven 3.8.x
* Tue Feb  2 2021 jengelh@inai.de
- Set buildshell to bash for "<<<".
* Tue Dec 29 2020 jgwang@suse.com
- Upgrade to upstream version 1.4.2
  * Bug:
    + MRESOLVER-38 – SOE/OOME in DefaultDependencyNode.accept
  * Improvements:
    + MRESOLVER-93 – PathRecordingDependencyVisitor to handle 3 cycles
    + MRESOLVER-102 – make build Reproducible
* Mon Dec  9 2019 fstrba@suse.com
- Upgrade to upstream version 1.4.1
  * Task
    + [MRESOLVER-92] - Revert MRESOLVER-7
  * Bug
    + [MRESOLVER-86] - ResolveArtifactMojo from resolver example
    uses plugin repositories to resolve dependencies
  * New Feature
    + [MRESOLVER-10] - New 'TransitiveDependencyManager'
    supporting transitive dependency management
    + [MRESOLVER-33] - New 'DefaultDependencyManager' managing
    dependencies on all levels supporting transitive dependency
    management
  * Improvement
    + [MRESOLVER-7] - Download dependency POMs in parallel
    + [MRESOLVER-84] - Add support for "release" qualifier
    + [MRESOLVER-87] - Refresh examples to use maven-resolver
    artifacts for demo
    + [MRESOLVER-88] - Code style cleanup to use Java 7 features
* Wed Mar 20 2019 fstrba@suse.com
- Initial packaging of maven-resolver 1.3.1
- Generate and customize the ant build files
- Added patch:
  * maven-resolver-1.3.1-java8compat.patch
    + avoid calling APIs added in Java 9
